#!/bin/bash

if [ $# -lt 3 ]; then
  echo "Invalid arguments. Please specify 'on' and the proxy server IP address and port number."
  exit 1
fi

if ! [[ "$3" =~ ^[0-9]+$ ]]; then
  echo "Invalid port number. Please specify a valid integer between 1 and 65535."
  exit 1
fi

PROXY_HOST="$2"
PROXY_PORT="$3"

# Check if the proxy server is reachable
ping -c 1 $PROXY_HOST > /dev/null
if [ $? -ne 0 ]; then
  echo "Could not reach the specified proxy server."
  exit 1
fi

DESKTOP_SESSION=$(echo $XDG_SESSION_DESKTOP | awk '{print tolower($0)}')

if [ "$1" = "on" ]; then
  case "$DESKTOP_SESSION" in
  ubuntu)
      gsettings set org.gnome.system.proxy mode 'manual'
      gsettings set org.gnome.system.proxy.http host ${PROXY_HOST}
      gsettings set org.gnome.system.proxy.http port ${PROXY_PORT}
      gsettings set org.gnome.system.proxy.https host ${PROXY_HOST}
      gsettings set org.gnome.system.proxy.https port ${PROXY_PORT}
      if [ "$(gsettings get org.gnome.system.proxy mode)" = "'manual'" ] && \
         [ "$(gsettings get org.gnome.system.proxy.http host)" = "'${PROXY_HOST}'" ] && \
         [ "$(gsettings get org.gnome.system.proxy.http port)" = "${PROXY_PORT}" ]
      then
         echo "Proxy settings have been successfully enabled for GNOME."
      else
         echo "Failed to enable proxy settings for GNOME."
      fi
      ;;
    gnome)
      gsettings set org.gnome.system.proxy mode 'manual'
      gsettings set org.gnome.system.proxy.http host ${PROXY_HOST}
      gsettings set org.gnome.system.proxy.http port ${PROXY_PORT}
      gsettings set org.gnome.system.proxy.https host ${PROXY_HOST}
      gsettings set org.gnome.system.proxy.https port ${PROXY_PORT}
      echo "Proxy settings have been enabled for GNOME."
       if [ "$(gsettings get org.gnome.system.proxy mode)" = "'manual'" ] && \
         [ "$(gsettings get org.gnome.system.proxy.http host)" = "'${PROXY_HOST}'" ] && \
         [ "$(gsettings get org.gnome.system.proxy.http port)" = "${PROXY_PORT}" ]
      then
         echo "Proxy settings have been successfully enabled for GNOME."
      else
         echo "Failed to enable proxy settings for GNOME."
      fi
      ;;
    kde)
      kwriteconfig5 --file kioslaverc --group 'Proxy Settings' --key ProxyType 1
      kwriteconfig5 --file kioslaverc --group 'Proxy Settings' --key httpProxy "http://${PROXY_HOST}:${PROXY_PORT}"
      kwriteconfig5 --file kioslaverc --group 'Proxy Settings' --key httpsProxy "https://${PROXY_HOST}:${PROXY_PORT}"
      if [ "$(kreadconfig5 --file kioslaverc --group 'Proxy Settings' --key ProxyType)" = "1" ] && [ "$(kreadconfig5 --file kioslaverc --group 'Proxy Settings' --key httpProxy)" = "http://${PROXY_HOST}:${PROXY_PORT}" ] && [ "$(kreadconfig5 --file kioslaverc --group 'Proxy Settings' --key httpsProxy)" = "https://${PROXY_HOST}:${PROXY_PORT}" ]
      then
          echo "Proxy settings have been successfully enabled for KDE."
      else
          echo "Failed to enable proxy settings for KDE."
      fi
      ;;
    xfce)
      xfconf-query -c xfce4-session -p /network/ProxyMode -s "manual"
      xfconf-query -c xfce4-session -p /network/HttpProxy -s "${PROXY_HOST}:${PROXY_PORT}"
      xfconf-query -c xfce4-session -p /network/HttpsProxy -s "${PROXY_HOST}:${PROXY_PORT}"
      if [ "$(xfconf-query -c xfce4-session -p /network/ProxyMode)" = "manual" ] && [ "$(xfconf-query -c xfce4-session -p /network/HttpProxy)" = "${PROXY_HOST}:${PROXY_PORT}" ] && [ "$(xfconf-query -c xfce4-session -p /network/HttpsProxy)" = "${PROXY_HOST}:${PROXY_PORT}" ]
      then
          echo "Proxy settings have been successfully enabled for XFCE."
      else
          echo "Failed to enable proxy settings for XFCE."
      fi
      ;;
    unity)
      gsettings set org.gnome.system.proxy mode 'manual'
      gsettings set org.gnome.system.proxy.http host ${PROXY_HOST}
      gsettings set org.gnome.system.proxy.http port ${PROXY_PORT}
      gsettings set org.gnome.system.proxy.https host ${PROXY_HOST}
      gsettings set org.gnome.system.proxy.https port ${PROXY_PORT}
       if [ "$(gsettings get org.gnome.system.proxy mode)" = "'manual'" ] && \
         [ "$(gsettings get org.gnome.system.proxy.http host)" = "'${PROXY_HOST}'" ] && \
         [ "$(gsettings get org.gnome.system.proxy.http port)" = "${PROXY_PORT}" ]
      then
         echo "Proxy settings have been successfully enabled for Unity."
      else
         echo "Failed to enable proxy settings for Unity."
      fi
      ;;
    *)
      echo "Failed to detect the current desktop environment."
      exit 1
      ;;
  esac
elif [ "$1" = "off" ]; then
  case "$DESKTOP_SESSION" in
    ubuntu)
      gsettings set org.gnome.system.proxy mode 'none'
       if [ "$(gsettings get org.gnome.system.proxy mode)" = "'none'" ]
      then
         echo "Proxy settings have been successfully disable"
      else
         echo "Failed to disable proxy settings for GNOME."
      fi
      ;;
    gnome)
      gsettings set org.gnome.system.proxy mode 'none'
       if [ "$(gsettings get org.gnome.system.proxy mode)" = "'none'" ]
      then
         echo "Proxy settings have been successfully disable"
      else
         echo "Failed to disable proxy settings for GNOME."
      fi
      ;;
    kde)
      kwriteconfig5 --file kioslaverc --group 'Proxy Settings' --key ProxyType 0
      if [ "$(kreadconfig5 --file kioslaverc --group 'Proxy Settings' --key ProxyType)" = "0" ]
      then
         echo "Proxy settings have been successfully disabled for KDE."
      else
         echo "Failed to disable proxy settings for KDE."
      fi

      ;;
    xfce)
      xfconf-query -c xfce4-session -p /network/ProxyMode -s "none"
      xfconf-query -c xfce4-session -p /network/HttpProxy -s ""
      xfconf-query -c xfce4-session -p /network/HttpsProxy -s ""
      if [ "$(xfconf-query -c xfce4-session -p /network/ProxyMode)" = "none" ]
      then
         echo "Proxy settings have been successfully disabled for XFCE."
      else
         echo "Failed to disable proxy settings for XFCE."
      fi
      ;;
    unity)
      gsettings set org.gnome.system.proxy mode 'none'
       if [ "$(gsettings get org.gnome.system.proxy mode)" = "'none'" ]
      then
         echo "Proxy settings have been successfully disabled for Unity."
      else
         echo "Failed to disable proxy settings for Unity."
      fi
      ;;
    *)
      echo "Failed to detect the current desktop environment."
      exit 1
      ;;
  esac
else
  echo "Invalid argument. Please specify either 'on' or 'off'."
  exit 1
fi

exit 0